PlayingWithFusion Libraries
===========================

These are not installed on the Robot by default. For installation instructions,
see :ref:`robotpy-playingwithfusion install docs <install_pwfusion>`.

This documentation documents the various classes and methods that are
available to Python code, but don't discuss in detail how to actually
set up, configure, and tune your PWF hardware. For that kind of information,
refer to the `Playing With Fusion software site <https://www.playingwithfusion.com/docview.php?docid=1205&catid=9012>`_.

.. toctree::
    
    playingwithfusion
